# discord.aio

> discord.aio is an asynchronous Discord API wrapper

*Currently under very early development*

## Documentation
You can find the module documentation here: https://ryozuki.github.io/discord.aio/docs

## Local development
- `git clone https://github.com/Ryozuki/discord.aio`
- `cd discord.aio && pip3 install -e .`

## TODO
- [Add compression support](https://discordapp.com/developers/docs/topics/gateway#encoding-and-compression)
- [Add bot shards support](https://discordapp.com/developers/docs/topics/gateway#get-gateway-bot)
- [Handle all discord events](https://discordapp.com/developers/docs/topics/gateway#commands-and-events-gateway-events)